==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/lib/plugins/usermanager/lang/es/lang.php <==
<?php
/**
 * Spanish language file
 *
 * @author Miguel Pagano <miguel.pagano>
 * @author Oscar M. Lage <r0sk10@gmail.com>
 * @author Gabriel Castillo <gch@pumas.ii.unam.mx>
 * @author oliver@samera.com.py
 */
$lang['menu']                  = 'Administración de usuarios';
$lang['noauth']                = '(la autentiación de usuariosuser no está disponible)';
$lang['nosupport']             = '(la administración de usuarios no está habilitada)';
$lang['badauth']               = 'Mecanismo de autenticación inválido';
$lang['user_id']               = 'Usuario';
$lang['user_pass']             = 'Contraseña';
$lang['user_name']             = 'Nombre';
$lang['user_mail']             = 'Correo electrónico';
$lang['user_groups']           = 'Grupos';
$lang['field']                 = 'Campo';
$lang['value']                 = 'Valor';
$lang['add']                   = 'Agregar';
$lang['delete']                = 'Eliminar';
$lang['delete_selected']       = 'Eliminar seleccionados';
$lang['edit']                  = 'Editar';
$lang['edit_prompt']           = 'Editar datos de este usuario';
$lang['modify']                = 'Guardar los cambios';
$lang['search']                = 'Buscar';
$lang['search_prompt']         = 'Realizar la búsqueda';
$lang['clear']                 = 'Limpiar los filtros de la búsqueda';
$lang['filter']                = 'Filtrar';
$lang['summary']               = 'Mostrando los usuarios %1$d-%2$d de %3$d encontrados. Cantidad total de usuarios %4$d.';
$lang['nonefound']             = 'No se encontraron usuarios que coincidan con los párametros de la búsqueda. Cantidad total de usuarios %d.';
$lang['delete_ok']             = '%d usuarios eliminados';
$lang['delete_fail']           = '%d no se pudieron eliminar.';
$lang['update_ok']             = 'Los datos del usuario se actualizaron exitosamente ';
$lang['update_fail']           = 'Los datos del usuario no se actualizaron';
$lang['update_exists']         = 'El cambio de nombre de usuario falló, el nombre especificado ($s) ya está en uso (los otros cambios se aplicaron).';
$lang['start']                 = 'primera';
$lang['prev']                  = 'anterior';
$lang['next']                  = 'siguiente';
$lang['last']                  = 'última';
$lang['edit_usermissing']      = 'El usuario seleccionado no ha sido encontrado; el usuario especificado puede haber sido eliminado o cambiado en algún otro lugar.';
$lang['user_notify']           = 'Notificar al usuario';
$lang['note_notify']           = 'El correo electrónico de notificación sólo será enviado si se actualizo la contraseña del usuario.';
$lang['note_group']            = 'Si no se especifica ningún grupo, los nuevos usuarios serán agregados al grupo por defecto (%s).';
$lang['add_ok']                = 'El usuario fue creado exitosamente.';
$lang['add_fail']              = 'Falló la creación del usuario';
$lang['notify_ok']             = 'Se envió la notificación por correo electrónico';
$lang['notify_fail']           = 'No se pudo enviar la notificación por correo electrónico';

==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/usermanager/lang/es/lang.php <==
<?php
/**
 * Spanish language file
 *
 * @author Miguel Pagano <miguel.pagano>
 * @author Oscar M. Lage <r0sk10@gmail.com>
 * @author Gabriel Castillo <gch@pumas.ii.unam.mx>
 * @author oliver@samera.com.py
 * @author Enrico Nicoletto <liverig@gmail.com>
 * @author Manuel Meco <manuel.meco@gmail.com>
 * @author VictorCastelan <victorcastelan@gmail.com>
 * @author Jordan Mero  hack.jord@gmail.com
 */
$lang['menu']                  = 'Administración de usuarios';
$lang['noauth']                = '(la autentiación de usuariosuser no está disponible)';
$lang['nosupport']             = '(la administración de usuarios no está habilitada)';
$lang['badauth']               = 'Mecanismo de autenticación inválido';
$lang['user_id']               = 'Usuario';
$lang['user_pass']             = 'Contraseña';
$lang['user_name']             = 'Nombre';
$lang['user_mail']             = 'Correo electrónico';
$lang['user_groups']           = 'Grupos';
$lang['field']                 = 'Campo';
$lang['value']                 = 'Valor';
$lang['add']                   = 'Agregar';
$lang['delete']                = 'Eliminar';
$lang['delete_selected']       = 'Eliminar seleccionados';
$lang['edit']                  = 'Editar';
$lang['edit_prompt']           = 'Editar datos de este usuario';
$lang['modify']                = 'Guardar los cambios';
$lang['search']                = 'Buscar';
$lang['search_prompt']         = 'Realizar la búsqueda';
$lang['clear']                 = 'Limpiar los filtros de la búsqueda';
$lang['filter']                = 'Filtrar';
$lang['summary']               = 'Mostrando los usuarios %1$d-%2$d de %3$d encontrados. Cantidad total de usuarios %4$d.';
$lang['nonefound']             = 'No se encontraron usuarios que coincidan con los párametros de la búsqueda. Cantidad total de usuarios %d.';
$lang['delete_ok']             = '%d usuarios eliminados';
$lang['delete_fail']           = '%d no se pudieron eliminar.';
$lang['update_ok']             = 'Los datos del usuario se actualizaron exitosamente ';
$lang['update_fail']           = 'Los datos del usuario no se actualizaron';
$lang['update_exists']         = 'El cambio de nombre de usuario falló, el nombre especificado ($s) ya está en uso (los otros cambios se aplicaron).';
$lang['start']                 = 'primera';
$lang['prev']                  = 'anterior';
$lang['next']                  = 'siguiente';
$lang['last']                  = 'última';
$lang['edit_usermissing']      = 'El usuario seleccionado no ha sido encontrado; el usuario especificado puede haber sido eliminado o cambiado en algún otro lugar.';
$lang['user_notify']           = 'Notificar al usuario';
$lang['note_notify']           = 'El correo electrónico de notificación sólo será enviado si se actualizo la contraseña del usuario.';
$lang['note_group']            = 'Si no se especifica ningún grupo, los nuevos usuarios serán agregados al grupo por defecto (%s).';
$lang['note_pass']             = 'Se generará una clave automáticamente si el campo izquierdo es vacío y se esta activo la notificación de usuario. ';
$lang['add_ok']                = 'El usuario fue creado exitosamente.';
$lang['add_fail']              = 'Falló la creación del usuario';
$lang['notify_ok']             = 'Se envió la notificación por correo electrónico';
$lang['notify_fail']           = 'No se pudo enviar la notificación por correo electrónico';
